@@ -1,38 +1,35 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 #
 #
 # A Net::DRI example for IRIS DCHK operations, currently only .DE
 
 use strict;
-use warnings;
 
 use Net::DRI;
 
-my ($dri,$rc);
+my $dri=Net::DRI->new(10);
+my $rc;
+
+eval {
 
-my $ok=eval {
-$dri=Net::DRI->new({cache_ttl => 10});
 $dri->add_registry('DENIC',{});
-$rc=$dri->target('DENIC')->add_current_profile('profile1','dchk');
+$rc=$dri->target('DENIC')->new_current_profile('profile1','dchk',{},[]);
 die($rc) unless $rc->is_success();
 display($dri,'denic.de');
 display($dri,'ecb.de');
-display($dri,'netdri-test-doesnotexist.de');
-display($dri,'1.5.3.2.7.2.9.6.9.4.e164.arpa'); ## example with ENUM domain names
 
 $dri->end();
 };
 
-if (! $ok)
+if ($@)
 { 
- my $err=$@;
  print "\n\nAn EXCEPTION happened !\n";
- if (ref $err)
+ if (ref($@))
  {
-  $err->print();
+  $@->print();
  } else
  {
-  print $err;
+  print($@);
  }
 } else
 {
@@ -47,13 +44,13 @@ sub display
  my ($dri,$dom)=@_;
  print 'DOMAIN: '.$dom."\n";
  my $rc=$dri->domain_info($dom);
- print 'IS_SUCCESS: '.$rc->is_success().' [CODE: '.$rc->code().' / '.$rc->native_code()."]\n";
- unless ($rc->is_success())
+ print 'IS_SUCCESS: '.$dri->result_is_success().' [CODE: '.$dri->result_code().' / '.$dri->result_native_code()."]\n";
+ unless ($dri->result_is_success())
  {
-  print $rc->message(),"\n";
+  print $dri->result_message(),"\n";
   return;
  }
- my $e=$dri->get_info('exist');
+ my $e=$dri->get_info('exist') || '?';
  print 'EXIST: '.$e."\n";
  if ($e eq '1')
  {
@@ -65,6 +62,6 @@ sub display
  }
  my $rs=$dri->get_info('result_status');
  print 'RESULT STATUS: ';
- $rs->print(1) if defined($rs);
+ $rs->print_full() if defined($rs);
  print "\n\n";
 }
