@@ -1,7 +1,6 @@
 ## Domain Registry Interface, Afilias ccTLD policies for .AG
 ##
-## Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##           (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,19 +11,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::AG;
 
-use utf8;
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
 use Net::DRI::Util;
 use DateTime::Duration;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -39,13 +40,13 @@ Please see the README file for details.
 
 For now, support questions should be sent to:
 
-E<lt>netdri@dotandco.comE<gt>
+E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 Please also see the SUPPORT file in the distribution.
 
 =head1 SEE ALSO
 
-E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>
+E<lt>http://oss.bsdprojects.net/projects/netdri/E<gt>
 
 =head1 AUTHOR
 
@@ -53,8 +54,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -73,7 +73,8 @@ sub new
  my $class=shift;
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
- $self->{info}->{contact_i18n}=2;
+
+ bless($self,$class);
  return $self;
 }
 
@@ -81,14 +82,23 @@ sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'Afilias AG'; }
 sub tlds     { return qw/ag com.ag net.ag org.ag nom.ag co.ag/; }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
-
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP::Extensions::Afilias',{}) if $type eq 'epp';
- return;
+ my ($drd,$ndr,$type,$ta,$pa)=@_;
+ $type='epp' if (!defined($type) || ref($type));
+ return Net::DRI::DRD::_transport_protocol_default_epp('Net::DRI::Protocol::EPP::Extensions::Afilias',$ta,$pa) if ($type eq 'epp');
 }
 
 ####################################################################################################
@@ -98,14 +108,32 @@ sub transport_protocol_default
 sub verify_name_domain
 {
  my ($self,$ndr,$domain,$op)=@_;
- return $self->_verify_name_rules($domain,$op,{ check_name => 1,
-                                                my_tld => 1,
-                                                no_double_hyphen => 1, ## http://www.nic.ag/reserved-names-policy.htm §1
-                                                no_country_code => 1,## http://www.nic.ag/reserved-names-policy.htm §6
-                                                no_digits_only => 1, ## http://www.nic.ag/reserved-names-policy.htm §4
-                                                excluded_labels => [qw/enum example localhost ns com edu ftp net whois wpad brand org tm co nom ac bd/], ## §7,8,9,10
-                                                ## Other names are banned in http://www.nic.ag/reserved-names-policy.htm §11,12 we do not implement all checks
-                                              });
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,[1,2]); ## one or two dots
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ 
+ my @d=split(/\./,$domain);
+ return 13 if substr($d[0],2,2) eq '--'; ## http://www.nic.ag/reserved-names-policy.htm 1
+ return 14 if exists($Net::DRI::Util::CCA2{uc($d[0])}); ## http://www.nic.ag/reserved-names-policy.htm 6
+ return 15 if ($d[0]=~m/^\d+$/); ## http://www.nic.ag/reserved-names-policy.htm 4
+ return 20 if (lc($d[0])=~m/^(?:enum|example|localhost|ns|com|edu|ftp|net|whois|wpad|brand|org|tm|co|nom|ac|bd)$/o); ## 7,8,9,10
+ ## Other names are banned in http://www.nic.ag/reserved-names-policy.htm 11,12 we do not implement all checks
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
+ return;
 }
 
 ####################################################################################################
