@@ -1,6 +1,6 @@
 ## Domain Registry Interface, BookMyName Registry Driver
 ##
-## Copyright (c) 2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::DRD::BookMyName;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,25 +71,74 @@ See the LICENSE file that comes with this distribution for more details.
 sub name { return 'BookMyName'; }
 sub tlds { return qw/com net org biz info name eu be us/; } ## As seen on http://api.doc.free.org/revendeur-de-nom-de-domaine
 sub object_types { return ('domain'); }
-sub profile_types { return qw/ws das/; }
 
-sub transport_protocol_default
+sub transport_protocol_compatible 
 {
- my ($self,$type)=@_;
-
- return ('Net::DRI::Transport::HTTP::SOAPLite',{uri=>'https://api.free.org/apis.cgi',proxy_uri=>'https://api.free.org/apis.cgi'},'Net::DRI::Protocol::BookMyName::WS',{}) if $type eq 'ws';
- return ('Net::DRI::Transport::Socket',{remote_host=>'das.bookmyname.com'},'Net::DRI::Protocol::DAS',{})                                                                  if $type eq 'das';
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
 
+ return 1 if (($pn eq 'bookmyname_ws')&& ($tn eq 'soaplite'));
  return;
 }
 
+sub transport_protocol_default
+{
+ my ($drd,$ndr,$type,$ta,$pa)=@_;
+ $type='ws' if (!defined($type) || ref($type));
+ if ($type eq 'ws')
+ {
+  return ('Net::DRI::Transport::HTTP::SOAPLite','Net::DRI::Protocol::BookMyName::WS') unless (defined($ta) && defined($pa));
+  my %ta=( 	has_login => 0,
+		has_logout => 0,
+		protocol_connection => 'Net::DRI::Protocol::BookMyName::WS::Connection',
+		protocol_version => 1,
+		uri => 'https://api.free.org/apis.cgi',
+		proxy_uri => 'https://api.free.org/apis.cgi',
+		defer => 1,
+		(ref($ta) eq 'ARRAY')? %{$ta->[0]} : %$ta,
+         );
+  my @pa=(ref($pa) eq 'ARRAY' && @$pa)? @$pa : ('1.0');
+  return ('Net::DRI::Transport::HTTP::SOAPLite',[\%ta],'Net::DRI::Protocol::BookMyName::WS',\@pa);
+ }
+}
+
 ####################################################################################################
 
+sub verify_name_domain
+{
+ my ($self,$ndr,$domain)=@_;
+ $domain=$ndr unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 0;
+}
+
 sub domain_operation_needs_is_mine
 {
  my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
  return;
 }
 
+sub account_list_domains
+{
+ my ($self,$ndr)=@_;
+ my $rc;
+ if (defined($ndr->get_info('list','account','domains')))
+ {
+  $ndr->set_info_from_cache('account','domains');
+  $rc=$ndr->get_info('result_status');
+ } else
+ {
+  $rc=$ndr->process('account','list_domains');
+ }
+ return $rc;
+}
+
 ####################################################################################################
 1;
