@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OpenSRS Registry Driver
 ##
-## Copyright (c) 2008-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::OpenSRS;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
 use DateTime::Duration;
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -54,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -77,54 +80,86 @@ sub new
 
 sub periods      { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name         { return 'OpenSRS'; }
-## See http://opensrs.com/site/services/domains/pricing
-sub tlds         { return (qw/com net org info biz mobi pro name asia tel/,
-                           qw/co me pw tv ws xxx jobs aero coop/,
-                           qw/ac ag ai ar br bz ca cc cl ec gd gs gy hn ht lc ms mx pe pm pr sr sx tc us uy vc ve vg/,
-                           qw/at be ch cz de dk es eu fi fr gr gg gl hr hu im is it je li lt lu lv md nl no pl pt ro ru se si ua uk/,
-                           qw/af am cn hk in io jp kg kr la mn my ph qa sg tl tm tw/,
-                           qw/ae cd cm il ly ma mu re sc sh so st to yt za/,
-                           qw/as au cx fm hm ki nu nz sb tf tk wf/,
-                          ); }
-sub object_types { return ('domain','ns'); }
-sub profile_types { return qw/xcp/; }
+sub tlds         { return (qw/com net org info biz mobi name asia at be ca cc ch cn de dk es eu fr it li me com.mx nl tv uk us/); } ## see http://services.tucows.com/services/domains/pricing.php
+sub object_types { return ('domain'); }
+
+sub transport_protocol_compatible 
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'opensrs_xcp') && ($tn eq 'http'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
-
- return ('Net::DRI::Transport::HTTP',{},'Net::DRI::Protocol::OpenSRS::XCP',{}) if $type eq 'xcp';
- return;
+ my ($drd,$ndr,$type,$ta,$pa)=@_;
+ if ($type eq 'xcp')
+ {
+  my %ta=(ref($ta) eq 'ARRAY')? %{$ta->[0]} : %$ta;
+  $ta{protocol_connection}='Net::DRI::Protocol::OpenSRS::XCP::Connection';
+  my @pa=(ref($pa) eq 'ARRAY' && @$pa)? @$pa : ();
+  return ('Net::DRI::Transport::HTTP',[\%ta],'Net::DRI::Protocol::OpenSRS::XCP',\@pa);
+ }
 }
 
 ####################################################################################################
 
+sub verify_name_domain
+{
+ my ($self,$ndr,$domain)=@_;
+ $domain=$ndr unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,[1,2]);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 0;
+}
+
 sub domain_operation_needs_is_mine
 {
  my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
  return;
 }
 
 sub account_list_domains
 {
  my ($self,$ndr)=@_;
- my $rc=$ndr->try_restore_from_cache('account','domains','list');
- if (! defined $rc) { $rc=$ndr->process('account','list_domains'); }
+ my $rc;
+ if (defined($ndr->get_info('list','account','domains')))
+ {
+  $ndr->set_info_from_cache('account','domains');
+  $rc=$ndr->get_info('result_status');
+ } else
+ {
+  $rc=$ndr->process('account','list_domains');
+ }
  return $rc;
 }
 
 sub domain_info
 {
  my ($self,$ndr,$domain,$rd)=@_;
- $self->enforce_domain_name_constraints($ndr,$domain,'info');
+ $self->err_invalid_domain_name($domain) if $self->verify_name_domain($domain,'info');
 
- my $rc=$ndr->try_restore_from_cache('domain',$domain,'info');
- if (! defined $rc)
+ my $rc;
+ my $exist;
+ ## After a successfull domain_info, get_info('ns') must be defined and is an Hosts object, even if empty
+ if (defined($exist=$ndr->get_info('exist','domain',$domain)) && $exist && defined($ndr->get_info('ns','domain',$domain)))
+ {
+  $ndr->set_info_from_cache('domain',$domain);
+  $rc=$ndr->get_info('result_status');
+ } else
  {
   ## First grab a cookie, if needed
   unless (Net::DRI::Util::has_key($rd,'cookie'))
   {
-   $rd=Net::DRI::Util::create_params('domain_info',$rd); ## will fail in set_cookie because other params needed, but at least this will be ok for next line ; otherwise do true checks of value needed
+   $rd={} unless defined($rd); ## will fail in set_cookie because other params needed, but at least this will be ok for next line ; otherwise do true checks of value needed
    $rd->{domain}=$domain;
    $rc=$ndr->process('session','set_cookie',[$rd]);
    return $rc unless $rc->is_success();
@@ -136,57 +171,5 @@ sub domain_info
  return $rc;
 }
 
-sub domain_update
-{
- my ($self,$ndr,$domain,$changes,$rd)=@_;
- $self->enforce_domain_name_constraints($ndr,$domain,'update');
-
- ## First grab a cookie, if needed
- unless (Net::DRI::Util::has_key($rd,'cookie'))
- {
-  $rd=Net::DRI::Util::create_params('domain_update',$rd); ## will fail in set_cookie because other params needed, but at least this will be ok for next line ; otherwise do true checks of value needed
-  $rd->{domain}=$domain;
-  my $rc=$ndr->process('session','set_cookie',[$rd]);
-  return $rc unless $rc->is_success();
-  $rd->{cookie}=$ndr->get_info('value','session','cookie'); ## Store cookie somewhere (taking into account date of expiry or some TTLs) ?
- }
- ## Now do the real update
- my $rc=$ndr->process('domain','update',[$domain,$changes,$rd]); ## the $domain is not really used here, as it was used during set_cookie above
- return $rc;
-}
-
-sub domain_is_mine
-{
- my ($self,$ndr,$domain,$rd)=@_;
- my $clid=$self->info('client_id');
- return unless defined $clid;
- my $rc=$ndr->process('domain','is_mine',[$domain,$rd]);
- return unless $rc->is_success();
- my $mine=$ndr->get_info('mine');
- return unless defined $mine;
- return $mine;
-}
-
-sub domain_send_authcode
-{
- my ($self,$ndr,$domain)=@_;
- my $rc=$ndr->process('domain','send_authcode',[$domain]);
- return $rc;
-}
-
-sub host_registry_check
-{
- my ($self,$ndr,$hostname,$registry)=@_;
-
- return $ndr->process('nameserver', 'registry_check', [$hostname, $registry]);
-}
-
-sub host_registry_add
-{
- my ($self,$ndr,$hostname,$rd)=@_;
-
- return $ndr->process('nameserver', 'registry_add', [$hostname, $rd]);
-}
-
 ####################################################################################################
-1;
+1;
\ No newline at end of file
