@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .TRAVEL policies
 ##
-## Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>,
+##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,17 +11,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::TRAVEL;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
+use Net::DRI::DRD::ICANN;
 use DateTime::Duration;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -42,7 +46,7 @@ Please also see the SUPPORT file in the distribution.
 
 =head1 SEE ALSO
 
-E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>
+E<lt>http://oss.bsdprojects.net/projects/netdri/E<gt>
 
 =head1 AUTHOR
 
@@ -50,9 +54,8 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>, SyGroup GmbH. 
-          (c) 2011 Patrick Mevzek <netdri@dotandco.com>.
-All rights reserved.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>,
+		   SyGroup GmbH. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -71,6 +74,7 @@ sub new
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
  $self->{info}->{contact_i18n}=6; ## INT only or INT+LOC (but not LOC only)
+ bless($self,$class);
  return $self;
 }
 
@@ -78,15 +82,25 @@ sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'TRAVEL'; }
 sub tlds     { return ('travel'); }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp whois/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return 1 if (($pn eq 'Whois') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
-
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP',{})                                  if $type eq 'epp';
- return ('Net::DRI::Transport::Socket',{remote_host=>'whois.nic.travel'},'Net::DRI::Protocol::Whois',{}) if $type eq 'whois';
- return;
+ my ($drd,$ndr,$type,$ta,$pa)=@_;
+ $type='epp' if (!defined($type) || ref($type));
+ return Net::DRI::DRD::_transport_protocol_default_epp('Net::DRI::Protocol::EPP',$ta,$pa) if ($type eq 'epp');
+ return ('Net::DRI::Transport::Socket',[{%Net::DRI::DRD::PROTOCOL_DEFAULT_WHOIS,remote_host=>'whois.nic.travel'}],'Net::DRI::Protocol::Whois',[]) if (lc($type) eq 'whois');
 }
 
 ####################################################################################################
@@ -94,10 +108,26 @@ sub transport_protocol_default
 sub verify_name_domain
 {
  my ($self,$ndr,$domain,$op)=@_;
- return $self->_verify_name_rules($domain,$op,{check_name => 1,
-                                               my_tld => 1,
-                                               icann_reserved => 1,
-                                              });
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 11 if Net::DRI::DRD::ICANN::is_reserved_name($domain,$op);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
+ return;
 }
 
 ####################################################################################################
