@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .BR EPP extensions
 ##
-## Copyright (c) 2008,2009,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::BR;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::BR;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,11 +67,18 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({brdomain=> 'urn:ietf:params:xml:ns:brdomain-1.0',
-            brorg   => 'urn:ietf:params:xml:ns:brorg-1.0',
+ my ($c,$drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::BR::Domain'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::BR::Contact'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::SecDNS'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ $self->ns({brdomain=> ['urn:ietf:params:xml:ns:brdomain-1.0','brdomain-1.0.xsd'],
+            brorg   => ['urn:ietf:params:xml:ns:brorg-1.0','brorg-1.0.xsd'],
            });
  $self->capabilities('domain_update','ticket',['set']);
  $self->capabilities('domain_update','release',['set']);
@@ -75,10 +86,8 @@ sub setup
  $self->capabilities('contact_update','associated_contacts',['add','del']);
  $self->capabilities('contact_update','responsible',['set']);
  $self->factories('contact',sub { return Net::DRI::Data::Contact::BR->new(); });
- return;
+ return $self;
 }
 
-sub default_extensions { return qw/BR::Domain BR::Contact SecDNS/; }
-
 ####################################################################################################
 1;
