@@ -1,6 +1,6 @@
 ## Domain Registry Interface, FCCN (.PT) EPP extensions
 ##
-## Copyright (c) 2008,2009,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::FCCN;
 
 use strict;
-use warnings;
 
+use Net::DRI::Data::Contact::FCCN;
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -60,21 +65,23 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp,$params)=@_;
- my $namespace_base = (defined($params) && ref($params) eq "HASH" && defined($params->{"namespace_base"})) ? $params->{"namespace_base"} : "http://www.dns.pt/xml/epp";
+ my ($c,$drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
 
- $self->ns({ ptdomain  => $namespace_base.'/ptdomain-1.0',
-             ptcontact => $namespace_base.'/ptcontact-1.0',
+ $e{'Net::DRI::Protocol::EPP::Extensions::FCCN::Contact'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::FCCN::Domain'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ $self->ns({ ptdomain  => ['http://www.dns.pt/xml/epp/ptdomain-1.0','ptdomain-1.0.xsd'],
+             ptcontact => ['http://www.dns.pt/xml/epp/ptcontact-1.0','ptcontact-1.0.xsd'],
            });
  $self->capabilities('contact_update','status',undef);
+ $self->factories('contact',sub { return Net::DRI::Data::Contact::FCCN->new(@_); });
  $self->default_parameters({domain_create => { auth => { pw => '' } } }); ## domain:authInfo is not used by FCCN
- return;
+ return $self;
 }
 
-sub default_extensions { return qw/FCCN::Contact FCCN::Domain/; }
-
 ####################################################################################################
 1;
