@@ -1,6 +1,6 @@
 ## Domain Registry Interface, FCCN (.PT) Contact EPP extension commands
 ##
-## Copyright (c) 2008,2009,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::FCCN::Contact;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,7 +68,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=(
+ my %tmp=( 
           create => [ \&create, undef ],
           update => [ \&update, undef ],
           info   => [ undef, \&info_parse ],
@@ -75,22 +79,32 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ return $mes->command_extension_register($tag,sprintf('xmlns:ptcontact="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('ptcontact')));
+}
+
 sub create
 {
  my ($epp,$contact)=@_;
+ my $mes=$epp->message();
 
 # validate() has been called
  my @n;
- push @n,['ptcontact:identification',$contact->identification()->{value}];
+ push @n,['ptcontact:type',$contact->type()];
+ push @n,['ptcontact:identification',{type=>$contact->identification()->{type}},$contact->identification()->{value}];
  push @n,['ptcontact:mobile',$contact->mobile()] if $contact->mobile();
 
- $epp->message()->command_extension('ptcontact', ['create', @n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'ptcontact:create');
+ $mes->command_extension($eid,\@n);
 }
 
+
 sub update
 {
  my ($epp,$contact,$todo)=@_;
+ my $mes=$epp->message();
 
  my @n;
  my $auth=$contact->auth();
@@ -100,12 +114,12 @@ sub update
  my $newc=$todo->set('info');
  if ($newc)
  {
-  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid contact '.$newc) unless Net::DRI::Util::isa_contact($newc,'Net::DRI::Data::Contact::FCCN');
+  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid contact '.$newc) unless Net::DRI::Util::isa_contact($newc);
   push @n,['ptcontact:mobile',$newc->mobile()] if $newc->mobile();
  }
 
- $epp->message()->command_extension('ptcontact', ['update', @n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'ptcontact:update');
+ $mes->command_extension($eid,\@n);
 }
 
 sub info_parse
@@ -137,7 +151,6 @@ sub info_parse
    $co->mobile($c->getFirstChild()->getData());
   }
  } continue { $c=$c->getNextSibling(); }
- return;
 }
 
 ####################################################################################################
