@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .PRO EPP extensions
 ##
-## Copyright (c) 2008,2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,15 +11,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::PRO;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION = do { my @r = (q$Revision: 1.1 $ =~ /\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -52,8 +54,7 @@ E<lt>http://www.hexonet.net/E<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,19 +68,29 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
+ my ($c,$drd, $version, $extrah, $defproduct) = @_;
+ my %e = map { $_ => 1 } (defined($extrah) ? (ref($extrah) ? @$extrah :
+	($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::PRO::Domain'} = 1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::PRO::AV'} = 1;
+ if (exists($e{':full'})) ## useful shortcut, modeled after Perl itself
+ {
+  delete($e{':full'});
+  $e{'Net::DRI::Protocol::EPP::Extensions::GracePeriod'} = 1;
+ }
+
+ my $self = $c->SUPER::new($drd, $version, [keys(%e)]);
 
  # Namespaces
- $self->ns({ av  => 'http://registrypro.pro/2003/epp/1/av-2.0',
-             rpro=> 'http://registrypro.pro/2003/epp/1/rpro-epp-2.0',
+ $self->ns({ av  => ['http://registrypro.pro/2003/epp/1/av-2.0', 'av-2.0.xsd'],
+             rpro=> ['http://registrypro.pro/2003/epp/1/rpro-epp-2.0','rpro-epp-2.0.xsd'],
            });
  $self->capabilities('domain_update','pro',['set']);
- return;
+ return $self;
 }
 
-sub default_extensions { return qw/PRO::Domain PRO::AV GracePeriod/; }
-
 ####################################################################################################
 1;
