@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Net::DRI::Protocol::EPP class for .SE
 ## Contributed by Elias Sidenbladh from NIC SE
 ##
-## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -14,7 +14,7 @@
 #
 # 
 #
-#########################################################################################
+####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::SE;
 
@@ -24,7 +24,7 @@ use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::SE;
 
-our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,18 +70,11 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
-    my $h=shift;
-    my $c=ref($h) || $h;
-
-    my ($drd,$version,$extrah)=@_;
+    my ($c,$drd,$version,$extrah)=@_;
     my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
     $e{'Net::DRI::Protocol::EPP::Extensions::SE::Extensions'}=1;
-    my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
-
-    my $rfact=$self->factories();
-    $rfact->{contact}=sub { return Net::DRI::Data::Contact::SE->new(); };
-
-    bless($self,$c); ## rebless
+    my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+    $self->factories('contact',sub { return Net::DRI::Data::Contact::SE->new(); });
     return $self;
 }
 
