@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Gandi Web Services Domain commands
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Gandi::WS::Domain;
 
 use strict;
-use warnings;
 
 use DateTime::Format::ISO8601;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
+use Net::DRI::Data::ContactSet;
+use Net::DRI::Data::Contact;
+use Net::DRI::Data::StatusList;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,8 +75,7 @@ sub register_commands
 {
  my ($class,$version)=@_;
  my %tmp=(
-		info  => [\&info, \&info_parse ],
-		check => [\&check, \&check_parse ],
+		info => [\&info, \&info_parse ],
 	  );
 
  return { 'domain' => \%tmp };
@@ -82,7 +88,6 @@ sub build_msg
  Net::DRI::Exception->die(1,'protocol/gandi/ws',10,'Invalid domain name') unless Net::DRI::Util::is_hostname($domain);
 
  $msg->method($command) if defined($command);
- return;
 }
 
 sub info
@@ -91,12 +96,11 @@ sub info
  my $msg=$po->message();
  build_msg($msg,'domain_info',$domain);
  $msg->params([$domain]);
- return;
 }
 
 sub info_parse
 {
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
+  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
  return unless $mes->is_success();
 
@@ -106,18 +110,19 @@ sub info_parse
  my %r=%$r;
  $rinfo->{domain}->{$oname}->{action}='info';
  $rinfo->{domain}->{$oname}->{exist}=1;
+ my $pd=DateTime::Format::ISO8601->new();
  my %d=(registry_creation_date => 'crDate', registry_last_update => 'upDate', registry_expiration_date => 'exDate', registrar_creation_date => 'trDate');
  while (my ($k,$v)=each(%d))
  {
   next unless exists($r{$k});
-  $rinfo->{domain}->{$oname}->{$v}=$po->parse_iso8601($r{$k});
+  $rinfo->{domain}->{$oname}->{$v}=$pd->parse_datetime($r{$k});
  }
  my %c=(owner_handle => 'registrant', admin_handle => 'admin', tech_handle => 'tech', billing_handle => 'billing');
- my $cs=$po->create_local_object('contactset');
- while (my ($k,$v)=each(%c))
+ my $cs=Net::DRI::Data::ContactSet->new();
+ while (my ($k,$v)=each(%d))
  {
   next unless exists($r{$k});
-  my $c=$po->create_local_object('contact')->srid($r{$k});
+  my $c=Net::DRI::Data::Contact->new()->srid($r{$k});
   $cs->add($c,$v);
  }
  $rinfo->{domain}->{$oname}->{contact}=$cs;
@@ -125,38 +130,14 @@ sub info_parse
 
  if ($r{locked})
  {
-  $rinfo->{domain}->{$oname}->{status}=$po->create_local_object('status')->add('clientTransferProhibited'); ## ?
+  $rinfo->{domain}->{$oname}->{status}=Net::DRI::Data::StatusList->new()->add('clientTransferProhibited'); ## ?
  } else
  {
-  $rinfo->{domain}->{$oname}->{status}=$po->create_local_object('status')->add('ok');
+  $rinfo->{domain}->{$oname}->{status}=Net::DRI::Data::StatusList->new()->add('ok');
  }
 
  ## And what about nameservers ? No information in documentation, only separate functions for that: domain_ns_*
  # $rinfo->{domain}->{$oname}->{ns}=??
- return;
-}
-
-sub check
-{
- my ($po,$domain)=@_;
- my $msg=$po->message();
- build_msg($msg,'domain_available',$domain);
- $msg->params([$domain]);
- return;
-}
-
-sub check_parse
-{
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
- my $mes=$po->message();
- return unless $mes->is_success();
-
- my $r=$mes->result();
- Net::DRI::Exception->die(1,'protocol/gandi/ws',1,'Unexpected reply for domain_check: '.$r) unless (ref($r) eq 'HASH');
-
- $rinfo->{domain}->{$oname}->{action}='check';
- $rinfo->{domain}->{$oname}->{exist}=(exists($r->{$oname}) && $r->{$oname}==1)? 0 : 1;
- return;
 }
 
 ####################################################################################################
