@@ -1,6 +1,6 @@
 ## Domain Registry Interface, IRIS Core functions
 ##
-## Copyright (c) 2008-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::IRIS::Core;
 
-use utf8;
 use strict;
-use warnings;
 
 use Carp;
 use Net::DRI::Protocol::ResultStatus;
-use Net::DRI::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,49 +78,28 @@ our %ERRORS=(insufficientResources => 2400,
              bagRefused => 2306,
             );
 
-sub parse_msglang
-{
- my ($c,$name)=@_;
- my (@i,$msg,$lang);
- foreach my $sn ($c->getChildrenByTagNameNS($c->namespaceURI(),$name))
- {
-  if (! defined $msg) { ($lang,$msg)=($sn->getAttribute('language'),$sn->textContent()); }
-  push @i,sprintf('[%s] %s',$sn->getAttribute('language'),$sn->textContent());
- }
- return (\@i,$msg,$lang);
-}
 
 sub parse_error
 {
- my ($node)=@_; ## $node should be a topmost <resultSet> to be able to catch all errors type
-
- foreach my $el (Net::DRI::Util::xml_list_children($node))
+ my ($mes,$node)=@_; ## $node should be a topmost <resultSet> to be able to catch all errors type
+ my $c=$node->getFirstChild();
+ while ($c)
  {
-  my ($name,$c)=@$el;
+  next unless ($c->nodeType() == 1); ## only for element nodes
+  my $name=$c->localname();
+  next unless $name;
   next if ($name eq 'answer' || $name eq 'additional');
   carp('Got unknown error <'.$name.'>, please report') unless exists($ERRORS{$name});
-  my ($ri,$msg,$lang)=parse_msglang($c,'explanation');
+  my (@i,$msg,$lang);
+  foreach my $expl ($c->getChildrenByTagNameNS($c->namespaceURI(),'explanation'))
+  {
+   ($msg,$lang)=($expl->getAttribute('language'),$expl->textContent()) unless defined($msg);
+   push @i,sprintf('[%s] %s',$expl->getAttribute('language'),$expl->textContent());
+  }
   ## We have only one error element at most, so break here if we found one
-  return Net::DRI::Protocol::ResultStatus->new('iris',$name,exists $ERRORS{$name} ? $ERRORS{$name} : 'COMMAND_FAILED',0,$msg,$lang,$ri);
- }
- return Net::DRI::Protocol::ResultStatus->new_success();
-}
-
-## RFC4991 §6 §7
-sub parse_authentication
-{
- my ($node)=@_; ## $node should be a topmost <resultSet> to be able to catch all errors type
- my ($ri,$msg,$lang);
-
- foreach my $el (Net::DRI::Util::xml_list_children($node))
- {
-  my ($name,$c)=@$el;
-  next unless ($name eq 'authenticationSuccess' || $name eq 'authenticationFailure');
-  ($ri,$msg,$lang)=parse_msglang($c,'description');
-  last;
- }
-
- return ($msg,$lang,$ri);
+  return Net::DRI::Protocol::ResultStatus->new('iris',$name,exists($ERRORS{$name})? $ERRORS{$name} : 'GENERIC_ERROR',0,$msg,$lang,\@i);
+ } continue { $c=$c->getNextSibling(); }
+ return Net::DRI::Protocol::ResultStatus->new_generic_success();
 }
 
 ####################################################################################################
