@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Protocol messages (pure virtual superclass)
 ##
-## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -21,7 +21,7 @@ use strict;
 
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -51,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,12 +63,14 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+####################################################################################################
 
 sub new           { Net::DRI::Exception::err_method_not_implemented(); }
 sub is_success    { Net::DRI::Exception::err_method_not_implemented(); }
 sub result_status { Net::DRI::Exception::err_method_not_implemented(); }
 sub parse         { Net::DRI::Exception::err_method_not_implemented(); }
-sub as_string     { Net::DRI::Exception::err_method_not_implemented(); }
 sub version       { Net::DRI::Exception::err_method_not_implemented(); }
 
+####################################################################################################
+
 1;
