@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OpenSRS XCP Message
 ##
-## Copyright (c) 2008-2010,2012-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,14 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::OpenSRS::XCP::Message;
 
 use strict;
-use warnings;
 
 use XML::LibXML ();
 
@@ -26,6 +28,8 @@ use Net::DRI::Util;
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version client_auth command command_attributes response_attributes response_code response_text response_is_success));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -54,7 +58,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2012-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -81,7 +85,6 @@ sub new
 our %CODES=( 200 => 1000,
              210 => 2303,
              211 => 2302,
-             212 => 1000,
              221 => 2302,
              250 => 1001,
              300 => 1001,
@@ -115,14 +118,15 @@ our %CODES=( 200 => 1000,
 sub result_status
 {
  my $self=shift;
- return Net::DRI::Protocol::ResultStatus->new_success($self->response_text()) if $self->response_is_success();
+ return Net::DRI::Protocol::ResultStatus->new_success('COMMAND_SUCCESSFUL',$self->response_text()) if ($self->response_is_success());
+
  my $code=$self->response_code();
- my $eppcode=(defined $code && exists $CODES{$code})? $CODES{$code} : 'COMMAND_FAILED';
+ my $eppcode=(!defined($code) || !exists($CODES{$code}))? 'GENERIC_ERROR' : $CODES{$code};
+
  return Net::DRI::Protocol::ResultStatus->new('opensrs_xcp',$code,$eppcode,$self->response_is_success(),$self->response_text(),'en');
 }
 
 sub is_success { return shift->response_is_success(); }
-sub as_string  { return shift->get_body(); }
 
 sub get_body
 {
@@ -138,7 +142,7 @@ sub get_body
  push @d,'<dt_assoc>';
  my $d=$self->command(); ## ref hash with at least action & object keys, maybe more (such as cookie)
  $d->{protocol}='XCP';
- foreach my $k (sort { $a cmp $b } keys %$d)
+ foreach my $k (sort(keys(%$d)))
  {
   push @d,'<item key="',$k,'">',$d->{$k},'</item>';
  }
@@ -156,7 +160,7 @@ sub _obj2dt
 {
  my ($in)=@_;
  my @r;
- foreach my $el ($in)
+ foreach my $el ((ref($in) eq 'ARRAY')? @$in : ($in))
  {
   my $ref=ref($el);
   if (!$ref)
@@ -165,15 +169,11 @@ sub _obj2dt
   } elsif ($ref eq 'HASH')
   {
    my @c;
-   foreach my $k (sort { $a cmp $b } keys %$el)
+   foreach my $k (sort(keys(%$el)))
    {
     $k=~s/"/&quot;/g;
     my $v=$el->{$k};
-    if (!defined($v)) {
-     push @c,sprintf('<item key="%s" />',$k);
-    } else {
-     push @c,sprintf('<item key="%s">%s</item>',$k,ref($v)? _obj2dt($v) : Net::DRI::Util::xml_escape($v));
-    }
+    push @c,sprintf('<item key="%s">%s</item>',$k,ref($v)? _obj2dt($v) : Net::DRI::Util::xml_escape($v));
    }
    push @r,sprintf('<dt_assoc>%s</dt_assoc>',join('',@c));
   } elsif ($ref eq 'ARRAY')
@@ -189,23 +189,23 @@ sub _obj2dt
    push @r,sprintf('<dt_scalarref>%s</dt_scalarref>',Net::DRI::Util::xml_escape($$el)); ## defined in specifications, but not really used ?
   } else
   {
-   Net::DRI::Exception::err_assert('_obj2dt cannot deal with data '.$el);
+   Net::DRI::Exception::err_assert('_obj2dt can not deal with data '.$el);
   }
  }
  return @r;
 }
 
-sub _dt2obj ## no critic (Subroutines::RequireFinalReturn)
+sub _dt2obj
 {
  my ($doc)=@_;
  my $c=$doc->getFirstChild();
  return unless defined($c);
  while (defined($c) && $c->nodeType()!=1) { $c=$c->getNextSibling(); }
- return $doc->textContent() unless (defined($c) && $c->nodeType()==1);
+ return $doc->getFirstChild()->getData() unless (defined($c) && $c->nodeType()==1);
  my $n=$c->nodeName();
  if ($n eq 'dt_scalar')
  {
-  return $c->textContent();
+  return $c->getFirstChild()->getData();
  } elsif ($n eq 'dt_assoc')
  {
   my %r;
@@ -235,14 +235,14 @@ sub parse
  my $parser=XML::LibXML->new();
  my $doc=$parser->parse_string($dr->as_string());
  my $root=$doc->getDocumentElement();
- Net::DRI::Exception->die(0,'protocol/OpenSRS/XCP',1,'Unsuccessful parse, root element is not OPS_envelope but '.$root->getName()) unless ($root->getName() eq 'OPS_envelope');
+ Net::DRI::Exception->die(0,'protocol/OpenSRS/XCP',1,'Unsuccessfull parse, root element is not OPS_envelope') unless ($root->getName() eq 'OPS_envelope');
 
  my $db=$root->getElementsByTagName('data_block');
- Net::DRI::Exception->die(0,'protocol/OpenSRS/XCP',1,'Unsuccessful parse, expected only one data_block node below root, found '.$db->size()) unless ($db->size()==1);
- $db=$db->get_node(1)->getChildrenByTagName('dt_assoc');
- Net::DRI::Exception->die(0,'protocol/OpenSRS/XCP',1,'Unsuccessful parse, expected one dt_assoc node directly below data_block, found '.$db->size()) unless ($db->size()==1);
+ Net::DRI::Exception->die(0,'protocol/OpenSRS/XCP',1,'Unsuccessfull parse, did not found only one data_block node below root') unless ($db->size()==1);
+ $db=$db->shift()->getChildrenByTagName('dt_assoc');
+ Net::DRI::Exception->die(0,'protocol/OpenSRS/XCP',1,'Unsuccessfull parse, did not found one dt_assoc node directly below data_block') unless ($db->size()==1);
 
- foreach my $item ($db->get_node(1)->getChildrenByTagName('item'))
+ foreach my $item ($db->shift()->getChildrenByTagName('item'))
  {
   my $key=$item->getAttribute('key');
   next if ($key eq 'protocol' || $key eq 'action' || $key eq 'object'); ## protocol is XCP, action is always REPLY, and we already have object in command()
@@ -253,22 +253,21 @@ sub parse
   }
   if ($key eq 'response_code') ## meaning is action-specific
   {
-   $self->response_code($item->textContent());
+   $self->response_code($item->getFirstChild()->getData());
    next;
   }
   if ($key eq 'response_text') ## meaning is action-specific
   {
-   $self->response_text($item->textContent());
+   $self->response_text($item->getFirstChild()->getData());
    next;
   }
   if ($key eq 'is_success') ## 0 if not successful, 1 if action was successful
   {
-   $self->response_is_success($item->textContent());
+   $self->response_is_success($item->getFirstChild()->getData());
    next;
   }
  }
- return;
 }
 
 ####################################################################################################
-1;
+1;
\ No newline at end of file
