@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Whois commands for .CAT (RFC3912)
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::CAT;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
 use Net::DRI::Protocol::Whois::Domain::common;
+use Net::DRI::Data::Contact::CAT;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -49,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -75,7 +80,6 @@ sub info
  my $mes=$po->message();
  Net::DRI::Exception->die(1,'protocol/whois',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  $mes->command(' -C US-ASCII ace '.lc($domain));
- return;
 }
 
 sub info_parse
@@ -86,24 +90,22 @@ sub info_parse
 
  my $rr=$mes->response();
  my $rd=$mes->response_raw();
- my ($domain,$exist)=parse_domain($po,$rr,$rd,$rinfo);
+ my ($domain,$exist)=parse_domain($rr,$rd,$rinfo);
  $domain=lc($oname) unless defined($domain);
  $rinfo->{domain}->{$domain}->{exist}=$exist;
  $rinfo->{domain}->{$domain}->{action}='info';
 
  return unless $exist;
-
- parse_registrars($po,$domain,$rr,$rinfo);
- parse_dates($po,$domain,$rr,$rinfo);
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_status($po,$domain,$rr,$rinfo);
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_contacts($po,$domain,$rr,$rinfo,{registrant => 'Registrant',admin => 'Admin', billing => 'Billing', tech => 'Tech'});
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_ns($po,$domain,$rr,$rinfo);
- return;
+ parse_registrar($domain,$rr,$rinfo);
+ parse_dates($domain,$rr,$rinfo);
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_status($domain,$rr,$rinfo);
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_contacts($domain,$rr,$rinfo,{registrant => 'Registrant',admin => 'Admin', billing => 'Billing', tech => 'Tech'},sub { return Net::DRI::Data::Contact::CAT->new() });
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_ns($domain,$rr,$rinfo);
 }
 
 sub parse_domain
 {
- my ($po,$rr,$rd,$rinfo)=@_;
+ my ($rr,$rd,$rinfo)=@_;
  my ($dom,$e);
  if (exists($rr->{'Domain Name'}))
  {
@@ -119,22 +121,20 @@ sub parse_domain
  return ($dom,$e);
 }
 
-sub parse_registrars
+sub parse_registrar
 {
- my ($po,$domain,$rr,$rinfo)=@_;
+ my ($domain,$rr,$rinfo)=@_;
  return unless exists($rr->{'Registrar ID'});
  ($rinfo->{domain}->{$domain}->{clID},$rinfo->{domain}->{$domain}->{clName})=($rr->{'Registrar ID'}->[0]=~m/^(\S+) \((.+)\)\s*$/);
- return;
 }
 
 sub parse_dates
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my $strp=$po->build_strptime_parser(pattern => '%Y-%m-%d %T GMT', time_zone => 'GMT');
+ my ($domain,$rr,$rinfo)=@_;
+ my $strp=DateTime::Format::Strptime->new(pattern => '%Y-%m-%d %T GMT', time_zone => 'GMT');
  $rinfo->{domain}->{$domain}->{crDate}=$strp->parse_datetime($rr->{'Created On'}->[0]);
  $rinfo->{domain}->{$domain}->{upDate}=$strp->parse_datetime($rr->{'Last Updated On'}->[0]);
  $rinfo->{domain}->{$domain}->{exDate}=$strp->parse_datetime($rr->{'Expiration Date'}->[0]);
- return;
 }
 
 ####################################################################################################
