@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Deferred Transport
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Transport::Defer;
 
-use strict;
-use warnings;
-
 use base qw(Net::DRI::Transport);
 
+use strict;
+
 use Net::DRI::Exception;
-use Net::DRI::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -34,7 +37,7 @@ This module implements a deferred transport in Net::DRI. For now it just dumps a
 to a given filehandle, and reports back to Net::DRI that the message has been sent.
 
 This is useful for debugging, and also to validate all parameters of an operation without
-actually sending anything to the registry ; in such way, it is kind of a "simulate" operation
+actually sending anything to the registry ; in such way, it is kind of a  simulate  operation
 where everything is done (parameters validation, message building, etc...) without touching
 the registry.
 
@@ -69,7 +72,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -85,19 +88,12 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$ctx,$rp)=@_;
- my %opts=%$rp;
+ my $class=shift;
+ my $drd=shift;
+ my $po=shift;
 
- my %t=();
- Net::DRI::Exception::usererr_insufficient_parameters('protocol_connection') unless (exists($opts{protocol_connection}) && $opts{protocol_connection});
- $t{pc}=$opts{protocol_connection};
- Net::DRI::Util::load_module($t{pc},'transport/defer');
- if ($t{pc}->can('transport_default'))
- {
-  %opts=($t{pc}->transport_default('defer'),%opts);
- }
-
- my $self=$class->SUPER::new($ctx,\%opts);
+ my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my $self=$class->SUPER::new(\%opts);
  $self->name('defer');
  $self->version('0.1');
  $self->has_state(0);
@@ -107,9 +103,12 @@ sub new
  $self->time_open(time());
  $self->time_used(time());
 
- $t{exchanges_done}=0;
+ my %t=(exchanges_done => 0);
  $t{dump_fh}=(exists($opts{dump_fh}))? $opts{dump_fh} : \*STDERR;
 
+ Net::DRI::Exception::usererr_insufficient_parameters('protocol_connection') unless (exists($opts{protocol_connection}) && $opts{protocol_connection});
+ $t{pc}=$opts{protocol_connection};
+ $t{pc}->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$t{pc},$@);
  my @need=qw/read_data write_message/;
  Net::DRI::Exception::usererr_invalid_parameters('protocol_connection class ('.$t{pc}.') must have: '.join(' ',@need)) if (grep { ! $t{pc}->can($_) } @need);
 
@@ -117,11 +116,12 @@ sub new
  return $self;
 }
 
+sub is_compatible_with_protocol { my ($self,$po)=@_; return 1; }
 sub ping {  return 1; }
 
-sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub send
 {
- my ($self,$ctx,$tosend)=@_;
+ my ($self,$trid,$tosend)=@_;
  my $t=$self->transport_data();
  my $pc=$t->{pc};
 
