@@ -1,6 +1,6 @@
 ## Domain Registry Interface, HTTP/HTTPS Transport
 ##
-## Copyright (c) 2008-2011,2013,2015 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,19 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Transport::HTTP;
 
-use strict;
-use warnings;
-
 use base qw(Net::DRI::Transport);
+use strict;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
 
-use LWP::UserAgent 6.02;
+use LWP::UserAgent;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -32,7 +35,7 @@ Net::DRI::Transport::HTTP - HTTP/HTTPS Transport for Net::DRI
 
 =head1 DESCRIPTION
 
-This module implements an HTTP/HTTPS transport for establishing connections in Net::DRI
+This module implements an HTTP/HTTPS stream for establishing connections in Net::DRI
 
 =head1 METHODS
 
@@ -42,19 +45,9 @@ At creation (see Net::DRI C<new_profile>) you pass a reference to an hash, with
 
 time to wait (in seconds) for server reply
 
-=head2 ssl_key_file ssl_cert_file ssl_ca_file ssl_ca_path ssl_cipher_list ssl_version ssl_passwd_cb
+=head2 https_debug https_version https_cert_file https_key_file https_ca_file https_ca_dir
 
-if C<remote_url> begins with https://, all key materials, see IO::Socket::SSL documentation for corresponding options
-
-=head2 ssl_verify
-
-see IO::Socket::SSL documentation about verify_mode (by default 0x00 here)
-
-=head2 ssl_verify_callback
-
-see IO::Socket::SSL documentation about verify_callback, it gets here as first parameter the transport object
-then all parameter given by IO::Socket::SSL; it is explicitly verified that the subroutine returns a true value,
-and if not the connection is aborted.
+all key materials for https access, if needed
 
 =head2 remote_url
 
@@ -70,7 +63,7 @@ protocol login & password
 
 =head2 protocol_connection
 
-Net::DRI class handling protocol connection details. Specifying it should not be needed, as the registry driver should have correct default values.
+Net::DRI class handling protocol connection details. (Ex: C<Net::DRI::Protocol::OpenSRS::XCP::Connection> or C<Net::DRI::Protocol::EPP::Extensions::PL::Connection>)
 
 =head2 protocol_data
 
@@ -78,17 +71,26 @@ Net::DRI class handling protocol connection details. Specifying it should not be
 For EPP, a key login_service_filter may exist, whose value is a code ref. It will be given an array of services, and should give back a
 similar array; it can be used to filter out some services from those given by the registry.
 
+=head2 log_fh
+
+(optional) either a reference to something that have a print() method or a filehandle (ex: \*STDERR or an anonymous filehandle) on something already opened for write ;
+if defined, all exchanges (messages sent to server, messages received from server) will be printed to this filehandle
+
 =head2 verify_response
 
 (optional) a callback (code ref) executed after each exchange with the registry, being called with the following parameters: the transport object,
 the phase (1 for greeting+login, 2 for all normal operations, 3 for logout), the count (if we retried multiple times to send the same message),
 the message sent (HTTP::Request object) and the response received (HTTP::Response object). This can be used to verify/diagnose SSL details,
-see example in file t/remote/opensrs_xcp.t
+see example in file t/704opensrs_xcp_live.t
 
 =head2 local_host
 
 (optional) the local address (hostname or IP) you want to use to connect (if you are multihomed)
 
+=head2 trid
+
+(optional) code reference of a subroutine generating transaction id ; if not defined, Net::DRI::Util::create_trid_1 is used
+
 =head1 SUPPORT
 
 For now, support questions should be sent to:
@@ -107,7 +109,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2011,2013,2015 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -121,73 +123,80 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
+## These ENV keys will be set each time just before doing HTTP stuff, making sure to remove pre-existing ones beforehand
+## This should enable us to deal with multiple endpoints with various parameters at the same time (BUT this should be really tested)
+our @HTTPS_ENV=qw/HTTPS_DEBUG HTTPS_VERSION HTTPS_CERT_FILE HTTPS_KEY_FILE HTTPS_CA_FILE HTTPS_CA_DIR/;
+
 sub new
 {
- my ($class,$ctx,$rp)=@_;
- my %opts=%$rp;
- my $ndr=$ctx->{registry};
- my $pname=$ctx->{profile};
- my $po=$ctx->{protocol};
+ my $class=shift;
+ my $drd=shift;
+ my $po=shift;
 
- my %t=(message_factory => $po->factories()->{message});
- Net::DRI::Exception::usererr_insufficient_parameters('protocol_connection') unless (exists($opts{protocol_connection}) && $opts{protocol_connection});
- $t{pc}=$opts{protocol_connection};
- Net::DRI::Util::load_module($t{pc},'transport/http');
- if ($t{pc}->can('transport_default'))
- {
-  %opts=($t{pc}->transport_default('http'),%opts);
- }
-
- my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
+ my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my $self=$class->SUPER::new(\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->has_state(1); ## some registries need login (like .PL) some not (like .ES) ; see end of method & call to open_connection()
  $self->is_sync(1);
  $self->name('http');
- $self->version('0.2');
+ $self->version($VERSION);
 
+ if (exists($opts{log_fh}) && defined($opts{log_fh})) ## convert to new api
+ {
+  $self->{logging}=[ \&_http_dump_to_filehandle,$opts{log_fh} ];
+ }
+
+ my %t=(message_factory => $po->factories()->{message});
+ $t{trid_factory}=(exists($opts{trid}) && (ref($opts{trid}) eq 'CODE'))? $opts{trid} : \&Net::DRI::Util::create_trid_1;
  foreach my $k (qw/client_login client_password client_newpassword protocol_data/)
  {
   $t{$k}=$opts{$k} if exists($opts{$k});
  }
-
+ Net::DRI::Exception::usererr_insufficient_parameters('protocol_connection') unless (exists($opts{protocol_connection}) && $opts{protocol_connection});
+ $t{pc}=$opts{protocol_connection};
+ $t{pc}->require() or Net::DRI::Exception::err_failed_load_module('transport/http',$t{pc},$@);
  my @need=qw/read_data write_message/;
  Net::DRI::Exception::usererr_invalid_parameters('protocol_connection class must have: '.join(' ',@need)) if (grep { ! $t{pc}->can($_) } @need);
  $t{protocol_data}=$opts{protocol_data} if (exists($opts{protocol_data}) && $opts{protocol_data});
- Net::DRI::Exception::usererr_insufficient_parameters('remote_url must be defined') unless (exists $opts{'remote_url'} && defined $opts{'remote_url'});
- Net::DRI::Exception::usererr_invalid_parameters('remote_url must be an uri starting with http:// or https:// with a proper path') unless $opts{remote_url}=~m!^https?://\S+/\S*$!;
+ Net::DRI::Exception::usererr_insufficient_parameters('remote_url must be defined') unless (exists($opts{'remote_url'}) && defined($opts{'remote_url'}) && $opts{remote_url}=~m!^https?://\S+/\S*$!);
  $t{remote_url}=$opts{remote_url};
- $t{remote_uri}=$t{remote_url}; ## only used for error messages
 
  my $ua=LWP::UserAgent->new();
- $ua->agent(sprintf('Net::DRI/%s ',$Net::DRI::VERSION)); ## the final space triggers LWP::UserAgent to add its own string
+ $ua->agent(sprintf('Net::DRI/%s Net::DRI::Transport::HTTP/%s ',$Net::DRI::VERSION,$VERSION)); ## the final space triggers LWP::UserAgent to add its own string
  $ua->cookie_jar({}); ## Cookies needed by some registries, like .PL (how strange !)
  ## Now some security settings
  $ua->max_redirect(0);
  $ua->parse_head(0);
  $ua->protocols_allowed(['http','https']);
  $ua->timeout($self->timeout()) if $self->timeout(); ## problem with our own alarm ?
- $ua->local_address($opts{local_host}) if exists $opts{local_host} && defined $opts{local_host};
+ $t{ua}=$ua;
 
- if ($t{remote_url}=~m!^https://!)
+ $t{local_host}=$opts{local_host} if (exists($opts{local_host}) && $opts{local_host});
+ $t{setenv}=0;
+ foreach my $k (map { lc } @HTTPS_ENV) ## Backport this stuff to other Transport modules in order to handle multiple differents sets of env values ?
  {
-  my %ssl=%{$self->parse_ssl_options(\%opts)};
-  while(my ($k,$v)=each %ssl)
-  {
-   $ua->ssl_opts($k,$v);
-  }
+  next unless (exists($opts{$k}) && defined($opts{$k}));
+  $t{setenv}=1;
+  $t{$k}=$opts{$k};
  }
 
- $t{ua}=$ua;
  $t{verify_response}=$opts{verify_response} if (exists($opts{verify_response}) && defined($opts{verify_response}) && (ref($opts{verify_response}) eq 'CODE'));
  $self->{transport}=\%t;
  $t{pc}->init($self) if $t{pc}->can('init');
 
- $self->open_connection($ctx); ## noop for registries without login, will properly setup has_state()
+ $self->open_connection(); ## noop for registries without login, will properly setup has_state()
  return $self;
 }
 
+sub _http_dump_to_filehandle ## not a class method
+{
+ my ($fh,$tname,$tversion,$trid,$step,$dir,$type,$data)=@_; ## $tname,$tversion,$step not used here
+ my $c=(ref($data) && UNIVERSAL::can($data,'as_string'))? $data->as_string() : $data; ## HTTP::{Request,Response} have an as_string() method !
+ Net::DRI::Transport::dump_to_filehandle($fh,$tname,$tversion,$trid,$step,$dir,2,$c);
+}
+
 sub send_login
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  my $t=$self->transport_data();
  my $pc=$t->{pc};
  my ($cltrid,$dr);
@@ -195,77 +204,73 @@ sub send_login
  ## Get registry greeting, if available
  if ($pc->can('greeting') && $pc->can('parse_greeting'))
  {
-  $cltrid=$self->generate_trid($self->{logging_ctx}->{registry}); ## not used for greeting (<hello> has no clTRID), but used in logging
-  my $greeting=$pc->greeting($t->{message_factory});
-  $self->log_output('notice','transport',$ctx,{trid=>$cltrid,phase=>'opening',direction=>'out',message=>$greeting});
-  Net::DRI::Exception->die(0,'transport/http',4,'Unable to send greeting message to '.$t->{remote_uri}) unless $self->_http_send(1,$greeting,1);
+  $cltrid=$t->{trid_factory}->($self->name()); ## not used for greeting (<hello> has no clTRID), but used in logging
+  my $greeting=$pc->greeting($self,$t->{message_factory});
+  $self->logging($cltrid,1,0,2,$greeting);
+  Net::DRI::Exception->die(0,'transport/http',4,'Unable to send greeting message') unless $self->_http_send(1,$greeting,1);
   $dr=$self->_http_receive(1);
-  $self->log_output('notice','transport',$ctx,{trid=>$cltrid,phase=>'opening',direction=>'in',message=>$dr});
+  $self->logging($cltrid,1,1,1,$dr);
   my $rc1=$pc->parse_greeting($dr); ## gives back a Net::DRI::Protocol::ResultStatus
   die($rc1) unless $rc1->is_success();
  }
 
- my $login=$pc->login($t->{message_factory},$t->{client_login},$t->{client_password},$cltrid,$dr,$t->{client_newpassword},$t->{protocol_data});
- $self->log_output('notice','transport',$ctx,{trid=>$cltrid,phase=>'opening',direction=>'out',message=>$login});
- Net::DRI::Exception->die(0,'transport/http',4,'Unable to send login message to '.$t->{remote_uri}) unless $self->_http_send(1,$login,1);
+ my $login=$pc->login($self,$t->{message_factory},$t->{client_login},$t->{client_password},$cltrid,$dr,$t->{client_newpassword},$t->{protocol_data});
+ $self->logging($cltrid,1,0,2,$login);
+ Net::DRI::Exception->die(0,'transport/http',4,'Unable to send login message') unless $self->_http_send(1,$login,1);
  $dr=$self->_http_receive(1);
- $self->log_output('notice','transport',$ctx,{trid=>$cltrid,phase=>'opening',direction=>'in',message=>$dr});
+ $self->logging($cltrid,1,1,1,$dr);
  my $rc2=$pc->parse_login($dr); ## gives back a Net::DRI::Protocol::ResultStatus
  die($rc2) unless $rc2->is_success();
- return;
 }
 
 sub open_connection
 {
- my ($self,$ctx)=@_;
+ my $self=shift;
  my $t=$self->transport_data();
  my $pc=$t->{pc};
  $self->has_state(0);
 
  if ($pc->can('login') && $pc->can('parse_login'))
  {
-  $self->send_login($ctx);
+  $self->send_login();
   $self->has_state(1);
   $self->current_state(1);
  }
-
  $self->time_open(time());
  $self->time_used(time());
  $self->transport_data()->{exchanges_done}=0;
- return;
+
 }
 
 sub send_logout
 {
- my ($self)=@_;
+ my $self=shift;
  my $t=$self->transport_data();
  my $pc=$t->{pc};
 
  return unless ($pc->can('logout') && $pc->can('parse_logout'));
 
- my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
- my $logout=$pc->logout($t->{message_factory},$cltrid);
- $self->log_output('notice','transport',{otype=>'session',oaction=>'logout'},{trid=>$cltrid,phase=>'closing',direction=>'out',message=>$logout});
- Net::DRI::Exception->die(0,'transport/http',4,'Unable to send logout message to '.$t->{remote_uri}) unless $self->_http_send(1,$logout,3);
+ my $cltrid=$t->{trid_factory}->($self->name());
+ my $logout=$pc->logout($self,$t->{message_factory},$cltrid);
+ $self->logging($cltrid,3,0,2,$logout);
+ Net::DRI::Exception->die(0,'transport/http',4,'Unable to send logout message') unless $self->_http_send(1,$logout,3);
  my $dr=$self->_http_receive(1);
- $self->log_output('notice','transport',{otype=>'session',oaction=>'logout'},{trid=>$cltrid,phase=>'closing',direction=>'in',message=>$dr});
+ $self->logging($cltrid,3,1,1,$dr);
  my $rc1=$pc->parse_logout($dr);
  die($rc1) unless $rc1->is_success();
- return;
 }
 
 sub close_connection
 {
- my ($self)=@_;
+ my $self=shift;
  $self->send_logout() if ($self->has_state() && $self->current_state());
  $self->transport_data()->{ua}->cookie_jar({});
  $self->current_state(0);
- return;
 }
 
 sub end
 {
- my ($self)=@_;
+ my $self=shift;
  if ($self->current_state())
  {
   eval
@@ -276,13 +281,12 @@ sub end
   };
   alarm(0); ## since close_connection may die, this must be outside of eval to be executed in all cases
  }
- return;
 }
 
-sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub send
 {
- my ($self,$ctx,$tosend)=@_;
- return $self->SUPER::send($ctx,$tosend,\&_http_send,sub {});
+ my ($self,$trid,$tosend)=@_;
+ $self->SUPER::send($trid,$tosend,\&_http_send,sub {});
 }
 
 sub _http_send
@@ -291,6 +295,19 @@ sub _http_send
  $phase=2 unless defined($phase); ## Phase 2 = normal operations (1=greeting+login, 3=logout)
  my $t=$self->transport_data();
 
+ ## Having two lines put the warnings away. This module is loaded by LWP::UserAgent anyway.
+ @LWP::Protocol::http::EXTRA_SOCK_OPTS=();
+ @LWP::Protocol::http::EXTRA_SOCK_OPTS=( LocalAddr => $t->{local_host} ) if exists($t->{local_host});
+ if ($t->{setenv})
+ {
+  foreach my $k (map { lc } @HTTPS_ENV)
+  {
+   delete($ENV{uc($k)});
+   next unless exists($t->{$k});
+   $ENV{uc($k)}=$t->{$k};
+  }
+ }
+
  ## Content-Length is automatically computed and added during the request() call, no need to do it before
  my $req=$t->{pc}->write_message($self,$tosend); ## gives back an HTTP::Request object
  Net::DRI::Util::check_isa($req,'HTTP::Request');
@@ -302,8 +319,8 @@ sub _http_send
 
 sub receive
 {
- my ($self,$ctx,$count)=@_;
- return $self->SUPER::receive($ctx,\&_http_receive);
+ my ($self,$trid)=@_;
+ return $self->SUPER::receive($trid,\&_http_receive);
 }
 
 sub _http_receive
