@@ -1,6 +1,6 @@
 ## Domain Registry Interface, XML-RPC Transport
 ##
-## Copyright (c) 2008-2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,20 +10,23 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Transport::HTTP::XMLRPCLite;
 
-use strict;
-use warnings;
-
 use base qw(Net::DRI::Transport);
+use strict;
 
 use Net::DRI::Exception;
 use Net::DRI::Data::Raw;
 use Net::DRI::Util;
 use XMLRPC::Lite;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -52,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,26 +70,17 @@ See the LICENSE file that comes with this distribution for more details.
 ####################################################################################################
 sub new
 {
- my ($class,$ctx,$rp)=@_;
- my %opts=%$rp;
- my $po=$ctx->{protocol};
-
- my %t=(message_factory => $po->factories()->{message});
- if (exists($opts{protocol_connection}) && $opts{protocol_connection})
- {
-  $t{protocol_connection}=$opts{protocol_connection};
-  Net::DRI::Util::load_module($t{protocol_connection},'transport/xmlrpclite');
-  if ($t{protocol_connection}->can('transport_default'))
-  {
-   %opts=($t{protocol_connection}->transport_default('xmlrpclite'),%opts);
-  }
- }
-
- my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
+ my $class=shift;
+ my $drd=shift;
+ my $po=shift;
+ my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my $self=$class->SUPER::new(\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->is_sync(1);
  $self->name('xmlrpclite');
- $self->version('0.1');
+ $self->version($VERSION);
 
+ my %t=(message_factory => $po->factories()->{message});
+ $t{trid_factory}=(exists($opts{trid}) && (ref($opts{trid}) eq 'CODE'))? $opts{trid} : \&Net::DRI::Util::create_trid_1;
  $t{has_login}=(exists($opts{has_login}) && defined($opts{has_login}))? $opts{has_login} : 0;
  $t{has_logout}=(exists($opts{has_logout}) && defined($opts{has_logout}))? $opts{has_logout} : 0;
  $self->has_state($t{has_login});
@@ -100,7 +94,7 @@ sub new
   $t{session_data}={};
  }
 
- foreach my $p (qw/protocol_connection proxy_uri/)
+ foreach my $p (qw/protocol_connection wsdl_uri proxy_uri servicename portname/)
  {
   Net::DRI::Exception::usererr_insufficient_parameters($p.' must be provided') unless (exists($opts{$p}) && defined($opts{$p}));
   $t{$p}=$opts{$p};
@@ -108,6 +102,7 @@ sub new
  Net::DRI::Exception::usererr_invalid_parameters('proxy_uri must be http:// or https://') unless ($t{proxy_uri}=~m!^https?://!);
 
  my $pc=$t{protocol_connection};
+ $pc->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$pc,$@);
  if ($t{has_login})
  {
   foreach my $m (qw/login parse_login extract_session/)
@@ -125,15 +120,16 @@ sub new
  }
 
  $self->{transport}=\%t;
+ bless($self,$class);
 
  if ($self->has_state())
  {
   if ($self->defer()) ## we will open, but later
   {
    $self->current_state(0);
-  } else ## we will open NOW
+  } else ## we will open NOW 
   {
-   $self->open_connection($ctx);
+   $self->open_connection();
   }
  } else
  {
@@ -144,23 +140,32 @@ sub new
  return $self;
 }
 
-sub soap { my ($self,$v)=@_; $self->{transport}->{soap}=$v if defined $v; return $self->{transport}->{soap}; }
-sub session_data { my ($self,$v)=@_; $self->{transport}->{session_data}=$v if defined $v; return $self->{transport}->{session_data}; }
+sub soap { my ($self,$v)=@_; $self->{transport}->{soap}=$v if @_==2; return $self->{transport}->{soap}; }
+sub session_data { my ($self,$v)=@_; $self->{transport}->{session_data}=$v if @_==2; return $self->{transport}->{session_data}; }
+
+sub soap_fault
+{
+ my($soap,$res)=@_; 
+ my $msg=ref($res)? $res->faultstring() : $soap->transport()->status();
+ Net::DRI::Exception->die(1,'transport/http/soapwsdl',7,'SOAP fault: '.$msg);
+}
 
 sub init
 {
  my ($self)=@_;
  return if defined($self->soap());
- my $soap=XMLRPC::Lite->new();
+ my $soap=SOAP::WSDL->new()->on_fault(\&soap_fault);
+ $soap->wsdl($self->{transport}->{wsdl_uri});
  $soap->proxy($self->{transport}->{proxy_uri});
- $soap->transport()->agent(sprintf('Net::DRI/%s ',$Net::DRI::VERSION).$soap->transport()->agent());
+ $soap->wsdlinit();
+ $soap->servicename($self->{transport}->{servicename});
+ $soap->portname($self->{transport}->{portname});
  $self->soap($soap);
- return;
 }
 
 sub send_login
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  my $t=$self->{transport};
  return unless $t->{has_login};
  foreach my $p (qw/client_login client_password/)
@@ -169,16 +174,18 @@ sub send_login
  }
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
+ my $cltrid=$t->{trid_factory}->($self->name());
  my $login=$pc->login($t->{message_factory},$t->{client_login},$t->{client_password},$cltrid);
- my $res=$self->_send_receive({otype=>'session',oaction=>'login',trid=>$cltrid,phase=>'opening'},$login);
+ my $res=$self->soap()->call( $login->method() => %{$login->params()});
+ ## $self->logging($cltrid,1,0,1,$login);
+ Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send login message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
+ ## $self->logging($cltrid,1,1,1,$dr);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res]));
  my $rc=$pc->parse_login($msg);
  die($rc) unless $rc->is_success();
 
  $self->session_data($pc->extract_session($msg));
- return;
 }
 
 sub send_logout
@@ -188,48 +195,28 @@ sub send_logout
  return unless $t->{has_logout};
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
+ my $cltrid=$t->{trid_factory}->($self->name());
  my $logout=$pc->logout($t->{message_factory},$cltrid,$t->{session_data});
- my $res=$self->_send_receive({otype=>'session',oaction=>'logout',trid=>$cltrid,phase=>'closing'},$logout);
+ my $res=$self->soap()->call( $logout->method() => %{$logout->params()});
+ ## $self->logging($cltrid,3,0,1,$logout);
+ Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send logout message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
+ ## $self->logging($cltrid,3,1,1,$dr);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res]));
  my $rc=$pc->parse_logout($msg);
  die($rc) unless $rc->is_success();
 
  $self->session_data({});
- return;
-}
-
-sub _send_receive ## no critic (Subroutines::RequireFinalReturn)
-{
- my ($self,$ctx,$msg)=@_;
- my $soap=$self->soap();
- my $err;
- my $res=$soap->on_fault(sub { (undef,$err)=@_; return; })->call($msg->method(),@{$msg->params()});
- if (my $httpres=$soap->transport()->http_response())
- {
-  $self->log_output('notice','transport',$ctx,{direction=>'out',message=>$httpres->request()});
-  $self->log_output('notice','transport',$ctx,{direction=>'in', message=>$httpres});
- } else
- {
-  $self->log_output('error','transport',$ctx,{direction=>'out',message=>'No response for message '.$soap->serializer()->envelope(method => $msg->method(), @{$msg->params()})});
- }
- return $res if defined $res && ref $res && ! $res->fault() && ! defined $err;
-
- Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP fault: '.$err->faultcode().' '.$err->faultstring()) if defined $err && ref $err;
- Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP transport error: '.$soap->transport()->status()) unless $soap->transport()->is_success();
- Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP deserialization error: '.$err);
 }
 
 sub open_connection
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  $self->init();
- $self->send_login($ctx);
+ $self->send_login();
  $self->current_state(1);
  $self->time_open(time());
  $self->time_used(time());
- return;
 }
 
 sub close_connection
@@ -238,12 +225,11 @@ sub close_connection
  $self->send_logout();
  $self->soap(undef);
  $self->current_state(0);
- return;
 }
 
 sub end
 {
- my ($self)=@_;
+ my $self=shift;
  if ($self->has_state() && $self->current_state())
  {
   eval
@@ -254,31 +240,30 @@ sub end
   };
   alarm(0); ## since close_connection may die, this must be outside of eval to be executed in all cases
  }
- return;
 }
 
 ####################################################################################################
 
-sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub send
 {
- my ($self,$ctx,$tosend)=@_;
- return $self->SUPER::send($ctx,$tosend,\&_soap_send,sub {});
+ my ($self,$trid,$tosend)=@_;
+ $self->SUPER::send($trid,$tosend,\&_soap_send,sub {});
 }
 
 sub _soap_send
 {
- my ($self,$count,$tosend,$ctx)=@_;
+ my ($self,$count,$tosend)=@_;
  my $t=$self->{transport};
- $tosend->add_session($self->session_data()) if $tosend->can('add_session');
- my $res=$self->_send_receive($ctx,$tosend);
+ $tosend->add_session($self->session_data());
+ my $res=$self->soap()->call( $tosend->method() => %{$tosend->params()});
  $t->{last_reply}=$res;
  return 1; ## very important
 }
 
 sub receive
 {
- my ($self,$ctx,$count)=@_;
- return $self->SUPER::receive($ctx,\&_soap_receive);
+ my ($self,$trid)=@_;
+ return $self->SUPER::receive($trid,\&_soap_receive);
 }
 
 sub _soap_receive
@@ -287,7 +272,7 @@ sub _soap_receive
  my $t=$self->{transport};
  my $r=$t->{last_reply};
  $t->{last_reply}=undef;
- return Net::DRI::Data::Raw->new(6,[$r]);
+ return Net::DRI::Data::Raw->new(1,[$r]);
 }
 
 ####################################################################################################
